<?php
/*******************************************************************************
*
*		    [ ./class_ftp.php ]
*
*	--------------------------------------------------------------------------
*	Commenc le : 	05 aout 2005
*	Copyright : 	Grummfy
*	Site Web : 		http://www.grummfy.com
*	E-mail : 		grummfy@yahoo.fr
*	--------------------------------------------------------------------------
*	Ce programme est libre, vous pouvez le redistribuer et/ou le modifier selon les 
*	termes de la Licence Publique Gnrale GNU publie par la Free Software Foundation 
*	(version 2). Reportez-vous  la Licence Publique Gnrale GNU pour plus de dtails. 
*	Vous devez avoir reu une copie de la Licence Publique Gnrale GNU en mme temps 
*	que ce programme ; si ce n'est pas le cas, crivez  la Free Software Foundation, 
*	Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, tats-Unis. 
*	--------------------------------------------------------------------------
*
*	Dernire modification le 05 aout 2005 par Grummfy
*
*******************************************************************************/

define('PHPVERSION',phpversion());
//
// erreur
//
// pas d'extension ftp charger
define('FTP_ERROR_NOFTP', -1);
// pas de connexion avec le serveur
define('FTP_ERROR_NOTCONNECT', -2);
// login ou password mauvais
define('FTP_ERROR_NOTLOGED', -3);
// impossible de suprime le fichier
define('FTP_ERROR_NOTDELETED', -4);
// impossible de changer le mode actif ou pasif de la connexion
define('FTP_ERROR_NOTACTIF', -5);

class FTP
{
	var $conn_id;
	var $login_result;
	var $error = array();

	// Se connecte au ftp distant
	// $host	:: adresse du serveur ftp
	// $login	:: nom d'utilisateur pour se connecter au ftp
	// $password	:: password pour se connecter au ftp
	// $actif	:: active ou dscative le mode passif (en mode passif c'est l'utilisateur et non le serveur qui dcide du chargement du fichier)
	// $ssl	:: connexion scuris
	// $port	:: port de conneion, par dfaut 21
	// $timeout	:: dlai de connexion, par dfaut 90
	function FTP($host, $login, $password, $actif = true, $ssl = false, $port = 21, $timeout = 90)
	{
		if(!extension_loaded("ftp"))
		{
			$this->error[] = FTP_ERROR_NOFTP;
			return false;
		}

		if ($ssl && PHPVERSION >= "4.3.0" && (!extension_loaded("OpenSSL") || !extension_loaded("oppenSSL") || !extension_loaded("openssl")) )
		{
			// Mise en place d'une connexion scurise
			$this->conn_id = ftp_ssl_connect($host, $port, $timeout);
		}
		else
		{
			// Mise en place d'une connexion basique
			if(PHPVERSION >= "4.2.0")
				$this->conn_id = ftp_connect($host, $port);
			else
				$this->conn_id = ftp_connect($host, $port, $timeout);
		}

		if (!$this->conn_id)
		{
			$this->error[] = FTP_ERROR_NOTCONNECT;
			return false;
		}

		// activation ou non du mode passif
		if ( !ftp_pasv( $this->conn_id, !$actif) )
		{
			$this->error[] = FTP_ERROR_NOTACTIF;
			return false;
		}

		// Identification avec un nom d'utilisateur et un mot de passe
		$this->login_result = ftp_login($this->conn_id, $login, $password);

		if (!$this->login_result)
		{
			$this->error[] = FTP_ERROR_NOTLOGED;
			return false;
		}
		return true;
	}

	// envoi le fichier sur le ftp
	// $destination	:: nom du fichier de destination
	// $source	:: nom du fichier source
	// $mode	:: mode de transfert de fichier (FTP_ASCII ou FTP_BINARY)
	function upload($destination, $source, $mode = FTP_BINARY)
	{
		// Chargement d'un fichier
		return ftp_put($this->conn_id, $destination, $source, $mode);
	}

	// tlcharge un fichier depuis le ftp
	// $destination	:: nom du fichier de destination
	// $source	:: nom du fichier source
	// $mode	:: mode de transfert de fichier (FTP_ASCII ou FTP_BINARY)
	function download($destination, $source, $mode = FTP_BINARY)
	{
		return ftp_get($this->conn_id, $destination, $source, $mode);
	}

	// suprime un fichier sur le ftp
	// $file	:: nom du fichier  suprimer
	// $is_dir	:: prcise si c'est un fichier ou un dossier (le dossier doit tre vide pour tre effac)
	function delete($file, $is_dir = false)
	{
		if($is_dir)
		{
			if ( !ftp_rmdir($this->conn_id, $file) )
			{
				$this->error[] = FTP_ERROR_NOTDELETED;
				return false;
			}
		}
		else
		{
			if ( !ftp_delete($this->conn_id, $file) )
			{
				$this->error[] = FTP_ERROR_NOTDELETED;
				return false;
			}
		}
		return true;
	}

	// renome un fichier
	// $file	:: nom du fichier
	// $new_name	:: nouveau nom
	function rename($file, $new_name)
	{
		return ftp_rename($this->conn_id, $file, $new_name);
	}

	// chmod un fichier distant
	// $file	:: nom du fichier
	// $chmod	:: chmod  effectuer sous la forme suivante : 0777 ou 0666 ....
	function chmod($file, $chmod)
	{
		if(PHPVERSION >= "5.0.0")
			return ftp_chmod($this->conn_id, $chmod, $file);
		else
			return ftp_site($this->conn_id, 'CHMOD ' . $chmod . ' ' . $file);
	}

	// ferme la connexion ftp
	function close()
	{
		// Fermeture du flux FTP
		ftp_close($this->conn_id);
	}

	// retourne un tableau avec toute les erreurs
	function ret_error()
	{
		return $this->error;
	}

	// liste les fichier dans le rpertoire ftp
	// $dir	:: rpertoire  scanner, peut avoir des argument (exemple : -la test/ pour lister le rpertoire test en donnant la date de cration d'un rpertoire etc...)
	// "R" est utilis pour utilis la rcurcivit
	// "la" donne une liste complte, date, chmod,...
	function liste_file($dir = '.')
	{
		return ftp_nlist($this->conn_id, $dir);
	}

	// permet de dfinir la taille ncssaire sur le serveur distant.
	// utiliser uniquement si nccssaire
	// uniquement valable en php5
	function alloc($file)
	{
		if(PHPVERSION < "5.0.0")
		{
			$this->error[] = 'php5 is needed!';
			return false;
		}

		if (ftp_alloc($this->conn_id, filesize($file), $result))
		{
			return true;
		}
		else
		{
			$this->error[] = $result;
			return false;
		}
	}
}

?>